# default name of the settings file which defines an DasboardApp application
DEFAULT_SETTINGS_FILE = "settings.py"

# default directory for implementation of dashboards
DEFAULT_DASHBOARDS_DIR = "dashboards"

# default name of the main file which runs the app
DEFAULT_RUNSERVER_FILE = "runserver.py"

# default name of the assets folder
DEFAULT_ASSETS_DIR = "assets"
